<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://wpextend.io
 * @since      1.0.0
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */

use Automattic\Jetpack\Constants;

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */
class Elementor_Connector_For_Woocommerce_Bookings_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Check that WooCommerce and WooCommerce Subscriptions are installed
	 *
	 * @since    1.0.0
	 */
	public function ecwb_plugins_loaded() {

		if ( true !== $this->ecwb_plugin_dependencies_met() ) {
			return;
		}
	}

	/**
	 * Display admin notice when WooCommerce or WooCommerce Subscriptions are not active.
	 *
	 * @since    1.0.0
	 */
	public function ecwb_plugin_dependencies_notice() {
		$return = $this->ecwb_plugin_dependencies_met( true );

		if ( true !== $return && current_user_can( 'activate_plugins' ) ) {
			$dependency_notice = $return;
			printf( '<div class="error"><p>%s</p></div>', wp_kses_post( $dependency_notice ) );
		}
	}

	/**
	 * Check whether the plugin dependencies met.
	 *
	 * @since    1.0.0
	 * @param    boolean $return_dep_notice       The state of dependent plugin installations/activations.
	 */
	private function ecwb_plugin_dependencies_met( $return_dep_notice = false ) {
		$return = false;

		if ( ! class_exists( 'Elementor\Plugin' ) ) {
			if ( $return_dep_notice ) {
				/* translators: %1$s: Opening Strong Tag, %2$s: Closing Strong Tag, %3$s: Opening WooCommerce Subscriptions link tag, %4$s: Closing link tag */
				$return = sprintf( esc_html__( '%1$sElementor Connector for WooCommerce Bookings is inactive.%2$s The %3$sElementor plugin%4$s must be active for this connector plugin to work.', 'elementor-connector-for-woocommerce-bookings' ), '<strong>', '</strong>', '<a href="https://wordpress.org/plugins/elementor/" target="_blank">', '</a>' );
			}

			return $return;
		}

		if ( ! class_exists( 'WC_Bookings' ) ) {
			if ( $return_dep_notice ) {
				/* translators: %1$s: Opening Strong Tag, %2$s: Closing Strong Tag, %3$s: Opening WooCommerce Subscriptions link tag, %4$s: Closing link tag */
				$return = sprintf( esc_html__( '%1$sElementor Connector for WooCommerce Bookings is inactive.%2$s The %3$sWooCommerce Bookings plugin%4$s must be active for this connector plugin to work.', 'elementor-connector-for-woocommerce-bookings' ), '<strong>', '</strong>', '<a href="http://woocommerce.com/products/woocommerce-bookings/" target="_blank">', '</a>' );
			}

			return $return;
		}

		if ( ! function_exists( 'WC' ) ) {
			if ( $return_dep_notice ) {
				$install_url = wp_nonce_url(
					add_query_arg(
						array(
							'action' => 'install-plugin',
							'plugin' => 'woocommerce',
						),
						admin_url( 'update.php' )
					),
					'install-plugin_woocommerce'
				);
				/* translators: %1$s: Opening Strong Tag, %2$s: Closing Strong Tag, %3$s: Opening WooCommerce link tag, %4$s: Closing link tag */
				$return = sprintf( esc_html__( '%1$sElementor Connector for WooCommerce Bookings is inactive.%2$s The %3$sWooCommerce plugin%4$s must be active for this connector plugin to work.', 'elementor-connector-for-woocommerce-bookings' ), '<strong>', '</strong>', '<a href="http://wordpress.org/extend/plugins/woocommerce/" target="_blank">', '</a>' );
			}

			return $return;
		}
		return true;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/elementor-connector-for-woocommerce-bookings-admin.css', array(), $this->version, 'all' );

		if ( defined( 'ELEMENTOR_ASSETS_URL' ) && defined( 'ELEMENTOR_VERSION' ) && class_exists( 'woocommerce' ) ) {
			if ( is_product() ) {
				wp_enqueue_style( 'font-awesome-5-all', ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/all.min.css', array(), ELEMENTOR_VERSION, 'all' );
			}
		}

		if ( class_exists( 'woocommerce' ) ) {
			$version = Constants::get_constant( 'WC_VERSION' );
			wp_register_style( 'select2', WC()->plugin_url() . '/assets/css/select2.css', '', $version, false );
			wp_enqueue_style( 'select2' );
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/elementor-connector-for-woocommerce-bookings-admin.js', array( 'jquery' ), $this->version, false );

		if ( class_exists( 'woocommerce' ) ) {
			wp_register_script( 'selectWoo', WC()->plugin_url() . '/assets/js/selectWoo/selectWoo.full.min.js', array( 'jquery' ), '1.0.6', true );
			wp_enqueue_script( 'selectWoo' );
		}
	}

	/**
	 * Register all the Elementor Connector for WooCommerce Bookings widgets.
	 *
	 * @param \Elementor\Widgets_Manager $widgets_manager Elementor widgets manager.
	 * @since    1.0.0
	 */
	public function ecwb_widget_init( $widgets_manager ) {

		require_once plugin_dir_path( __DIR__ ) . '/admin/class-elementor-connector-for-woocommerce-bookings-single-product-form.php';
		$widgets_manager->register( new \Elementor_Connector_For_Woocommerce_Bookings_Single_Product_Form() );

		require_once plugin_dir_path( __DIR__ ) . '/admin/class-elementor-connector-for-woocommerce-bookings-single-page-form.php';
		$widgets_manager->register( new \Elementor_Connector_For_Woocommerce_Bookings_Single_Page_Form() );
	}

	/**
	 * Set HPOS compatibility.
	 *
	 * @since 1.7
	 */
	public function ecwb_set_hpos_compatibility() {
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', 'elementor-connector-for-woocommerce-bookings/elementor-connector-for-woocommerce-bookings.php', true );
		}
	}

	/**
	 * Set Cart/Checkout Block compatibility.
	 *
	 * @since 1.9
	 */
	public function ecwb_set_block_compatibility() {
		if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'cart_checkout_blocks', 'elementor-connector-for-woocommerce-bookings/elementor-connector-for-woocommerce-bookings.php', true );
		}
	}
}
