<?php
/**
 * Elementor Connector for WooCommerce Bookings - Bookings Form Widget.
 *
 * Elementor widget that inserts bookable form on the single product page.
 *
 * @since 1.0.0
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Popover_Toggle;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Elementor widget used in admin.
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */
class Elementor_Connector_For_Woocommerce_Bookings_Single_Page_Form extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ecwb-booking-page-form';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'WC Bookings Calendar - Posts/Pages', 'elementor-connector-for-woocommerce-bookings' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-thumbnails-half';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'woocommerce-elements' );
	}

	/**
	 * Get widget keywords.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return array( 'woocommerce', 'shop', 'store', 'cart', 'product', 'button', 'add to cart', 'bookings', 'form', 'calendar' );
	}

	/**
	 * Find Elementor data for current post.
	 *
	 * @since 1.4.0
	 *
	 * @param string     $needle  Name of data we are looking for.
	 * @param mixed|null $default_value Default value to return if nothing is found.
	 * @return mixed
	 */
	protected function find_elementor_data( $needle, $default_value = '' ) {
		$post = get_post();
		if ( ! $post ) {
			return $default_value;
		}

		$meta = get_post_meta( $post->ID );
		if ( empty( $meta ) || empty( $meta['_elementor_data'] ) ) {
			return $default_value;
		}

		foreach ( $meta['_elementor_data'] as $data ) {
			$arr = json_decode( $data, true );
			if ( is_array( $arr ) ) {
				$value = $this->find_recursively( $arr, $needle );
				if ( isset( $value ) ) {
					return $value;
				}
			}
		}

		return $default_value;
	}

	/**
	 * Recursively loop through Elementor Data to find assigned product ID.
	 *
	 * @since 1.4.0
	 *
	 * @param array  $haystack The elementor post meta array.
	 * @param string $needle   Name of data we are looking for.
	 * @return mixed
	 */
	protected function find_recursively( array $haystack, $needle ) {
		$iterator  = new RecursiveArrayIterator( $haystack );
		$recursive = new RecursiveIteratorIterator(
			$iterator,
			RecursiveIteratorIterator::SELF_FIRST
		);

		foreach ( $recursive as $key => $value ) {
			if ( $key === $needle ) {
				return $value;
			}
		}
	}

	/**
	 * Retrieve the bookable product based on elementor meta.
	 *
	 * @since 1.0.0
	 *
	 * @return WC_Product|false
	 */
	protected function get_bookable_product() {
		$atts_product_id = $this->find_elementor_data( 'ecwb_content_section_bookable_product_id' );
		if ( empty( $atts_product_id ) ) {
			return false;
		}
		$product = wc_get_product( $atts_product_id );
		return $product ? $product : false;
	}

	/**
	 * Check if bookable product has persons configured.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function ecwb_has_persons() {
		$product = $this->get_bookable_product();
		if ( ! $product || 'booking' !== $product->get_type() ) {
			return false;
		}
		return $product->has_persons();
	}

	/**
	 * Check if bookable product has resources configured.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function ecwb_has_resources() {
		$product = $this->get_bookable_product();
		if ( ! $product || 'booking' !== $product->get_type() ) {
			return false;
		}
		return $product->has_resources();
	}

	/**
	 * Check if bookable product has timeslots configured.
	 *
	 * @since 1.0.0
	 *
	 * @return mixed 'fixed', 'customer' or false.
	 */
	public function ecwb_has_timeslots() {
		$product = $this->get_bookable_product();
		if ( ! $product || 'booking' !== $product->get_type() ) {
			return false;
		}

		$timeslots_type = $product->get_duration_type();
		if ( 'fixed' === $timeslots_type ) {
			return 'fixed';
		}
		if ( 'customer' === $timeslots_type ) {
			return 'customer';
		}
		return false;
	}

	/**
	 * Check if bookable product uses "month" as duration unit.
	 *
	 * @since 1.2.0
	 *
	 * @return string Duration unit, defaults to 'day'.
	 */
	public function ecwb_is_monthly() {
		$product = $this->get_bookable_product();
		if ( ! $product || 'booking' !== $product->get_type() ) {
			return 'day';
		}
		return $product->get_duration_unit();
	}

	/**
	 * Check if bookable product is an accommodation booking.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	public function ecwb_is_accommodation() {
		$product = $this->get_bookable_product();
		if ( ! $product || 'accommodation-booking' !== $product->get_type() ) {
			return false;
		}
		return true;
	}

	/**
	 * Render the booking calendar of the product that is specified by ID.
	 *
	 * @since 1.4.0
	 */
	public function ecwb_get_booking_calendar() {
		$settings = $this->get_settings_for_display();
		$product  = $this->get_bookable_product();

		if ( ! $product ) {
			return;
		}

		if ( ! $product->is_purchasable() ) {
			return;
		}

		$nonce = wp_create_nonce( 'find-booked-day-blocks' );
		do_action( 'woocommerce_before_add_to_cart_form' );
		?>
		<noscript><?php esc_html_e( 'Your browser must support JavaScript in order to make a booking.', 'elementor-connector-for-woocommerce-bookings' ); ?></noscript>
		<form class="cart" method="post" enctype="multipart/form-data" data-nonce="<?php echo esc_attr( $nonce ); ?>">
			<div id="wc-bookings-booking-form" class="wc-bookings-booking-form" style="display:none">
				<?php
				do_action( 'woocommerce_before_booking_form' );
				$booking_form = new WC_Booking_Form( $product );
				$booking_form->output();
				?>
				<div class="wc-bookings-booking-cost price" style="display:none" data-raw-price=""></div>
			</div>
			<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>
			<input type="hidden" name="add-to-cart" value="<?php echo esc_attr( is_callable( array( $product, 'get_id' ) ) ? $product->get_id() : $product->id ); ?>" class="wc-booking-product-id" />
			<button type="submit" class="wc-bookings-booking-form-button single_add_to_cart_button button alt disabled" style="display:none">
				<?php echo esc_html( $product->single_add_to_cart_text() ); ?>
			</button>
			<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		</form>
		<?php
		do_action( 'woocommerce_after_add_to_cart_form' );
	}

	/**
	 * Render widget in HTML on front-end.
	 *
	 * @since 1.0.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$this->ecwb_get_booking_calendar();
	}

	/**
	 * Get product ID of the selected bookable product.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function get_wc_bookable_product_id() {
		$args = array(
			'post_type'      => 'product',
			'posts_per_page' => -1,
			'tax_query'      => array( // phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_tax_query
				array(
					'taxonomy' => 'product_type',
					'field'    => 'slug',
					'terms'    => 'booking',
				),
			),
		);

		$query    = new WP_Query( $args );
		$products = array();

		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$products[ get_the_ID() ] = 'ID: ' . get_the_ID() . ' - ' . get_the_title();
			}
		}

		wp_reset_postdata();

		return $products;
	}

	/**
	 * Generate Elementor option panel for widget.
	 *
	 * @since 1.0.0
	 */
	protected function register_controls() {

		$ecwb_get_persons_meta     = $this->ecwb_has_persons();
		$ecwb_get_resources_meta   = $this->ecwb_has_resources();
		$ecwb_get_timeslots_meta   = $this->ecwb_has_timeslots();
		$ecwb_get_bookingtype_meta = $this->ecwb_is_accommodation();
		$ecwb_get_duration_unit    = $this->ecwb_is_monthly();

		$ecwb_should_display_calendar = ( 'month' === $ecwb_get_duration_unit ) ? false : true;

		$this->start_controls_section(
			'ecwb_content_section',
			array(
				'label' => __( 'Content', 'elementor-connector-for-woocommerce-bookings' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			)
		);

			$this->add_control(
				'ecwb_content_section_bookable_product_heading',
				array(
					'label' => __( 'Product', 'elementor-connector-for-woocommerce-bookings' ),
					'type'  => Controls_Manager::HEADING,
				)
			);

			$this->add_control(
				'ecwb_content_section_bookable_product_id',
				array(
					'label'       => __( 'Bookable Product', 'elementor-connector-for-woocommerce-bookings' ),
					'type'        => Controls_Manager::SELECT2,
					'default'     => '',
					'options'     => $this->get_wc_bookable_product_id(),
					'label_block' => true,
					'description' => __( 'Enter the ID of the bookable product to display. Can be found under Products > All Products', 'elementor-connector-for-woocommerce-bookings' ),
				)
			);

		$this->end_controls_section();

		if ( true === $ecwb_get_persons_meta ) {
			$this->start_controls_section(
				'ecwb_person_styles',
				array(
					'label' => __( 'Persons', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-persons.php';

			$this->end_controls_section();
		}

		if ( true === $ecwb_get_resources_meta ) {

			$this->start_controls_section(
				'ecwb_resource_styles',
				array(
					'label' => __( 'Resources', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-resources.php';

			$this->end_controls_section();
		}

		if ( true === $ecwb_should_display_calendar ) {

			$this->start_controls_section(
				'ecwb_calendar_styles',
				array(
					'label' => __( 'Calendar', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

				require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-calendar.php';

			$this->end_controls_section();
		}

		if ( true === $ecwb_get_bookingtype_meta ) {

			$this->start_controls_section(
				'ecwb_accommodation_styles',
				array(
					'label' => __( 'Check-in/out', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

				require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-accommodation.php';

			$this->end_controls_section();
		}

		if ( 'fixed' === $ecwb_get_timeslots_meta ) {
			$this->start_controls_section(
				'ecwb_timeslots_styles_fixed',
				array(
					'label' => __( 'Timeslots: Fixed', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-timeslots-fixed.php';

			$this->end_controls_section();
		}

		if ( 'customer' === $ecwb_get_timeslots_meta ) {
			$this->start_controls_section(
				'ecwb_timeslots_styles_customer',
				array(
					'label' => __( 'Timeslots: Customer Defined', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-timeslots-customer.php';

			$this->end_controls_section();
		}

		$this->start_controls_section(
			'ecwb_costs_styles',
			array(
				'label' => __( 'Costs & Notices', 'elementor-connector-for-woocommerce-bookings' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-costs.php';

		$this->end_controls_section();

		$this->start_controls_section(
			'ecwb_buttons_styles',
			array(
				'label' => __( 'Buttons', 'elementor-connector-for-woocommerce-bookings' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-buttons.php';

		$this->end_controls_section();

		if ( 'yes' === get_option( 'woocommerce_show_marketplace_suggestions' ) ) {
			$this->start_controls_section(
				'ecwb_templates',
				array(
					'label' => __( 'Templates', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);

				require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-templates.php';

			$this->end_controls_section();
		}
	}

	/**
	 * Render backbone.js view of widget preview.
	 *
	 * @since 1.0.0
	 */
	public function render_plain_content() {
		$this->content_template();
	}

	/**
	 * Generate the live preview in the Elementor admin area.
	 *
	 * @since 1.0.0
	 */
	protected function content_template() {
		$ecwb_get_persons_meta     = $this->ecwb_has_persons();
		$ecwb_get_resources_meta   = $this->ecwb_has_resources();
		$ecwb_get_timeslots_meta   = $this->ecwb_has_timeslots();
		$ecwb_get_bookingtype_meta = $this->ecwb_is_accommodation();
		$ecwb_get_duration_unit    = $this->ecwb_is_monthly();
		?>
		<style type="text/css">
			/* Styles to be used in Admin Elementor Widget only. */
			.elementor-widget-ecwb-booking-form form {
				display: block !important;
			}

			.elementor-editor-active #ecwb-elementor-admin-form:before {
				visibility: hidden;
			}

			.elementor-editor-active .elementor-widget-ecwb-booking-page-form:hover #ecwb-elementor-admin-form:before {
				visibility: visible;
			}

			.elementor-editor-active #ecwb-elementor-admin-form:before {
				background: var(--e-p-border-widget, #f3bafd);
				position: absolute;
				content: "<?php esc_attr_e( 'Static demo widget only. Actual values used on front-end.', 'elementor-connector-for-woocommerce-bookings' ); ?>";
				font-size: 12px;
				color: var(--e-p-border-widget-invert, #0c0d0e);
				top: 0;
				left: 0;
				width: 100%;
				height: 25px;
				padding: 0 0.7em;
				line-height: 25px;
			}

			.elementor-editor-active .elementor-widget-ecwb-booking-form:hover #ecwb-elementor-admin-form {
				margin-top: 25px;
			}

			#wc-bookings-booking-form fieldset,
			#wc-bookings-booking-form table {
				border: none;
				width: 100%;
			}

			#wc-bookings-booking-form .form-field input[type=number] {
				width: auto;
			}

			.elementor-widget-ecwb-booking-form table:not( .has-background ) tbody tr:nth-child(2n) td,
			.elementor-widget-ecwb-booking-form fieldset,
			.elementor-widget-ecwb-booking-form fieldset legend {
				background: transparent;
			}
		</style>
		<form class="cart" method="post" enctype="multipart/form-data" data-nonce="cf7fbe13ed" id="ecwb-elementor-admin-form">
			<div id="wc-bookings-booking-form" class="wc-bookings-booking-form">
			<?php if ( 'month' !== $ecwb_get_duration_unit ) { ?>
				<?php if ( true === $ecwb_get_persons_meta ) { ?>
					<p class="form-field form-field-wide wc_bookings_field_persons_154">
						<label for="wc_bookings_field_persons_154">Person Type #0:</label>
						<input type="number" value="0" step="1" min="0" max="1" name="wc_bookings_field_persons_154" id="wc_bookings_field_persons_154">
					</p>
				<?php } ?>
				<?php if ( true === $ecwb_get_resources_meta ) { ?>
					<p class="form-field form-field-wide wc_booking_field_ wc_bookings_field_resource">
						<label for="wc_bookings_field_resource">Type:</label>
						<select name="wc_bookings_field_resource" id="wc_bookings_field_resource">
							<option value="153">Tables (+$10.00)</option>
						</select>
					</p>
				<?php } ?>
				<fieldset class="wc-bookings-date-picker wc_bookings_field_start_date wc-bookings-date-picker-accommodation-booking">
					<div class="picker hasDatepicker" data-display="always_visible" data-default-availability="false" data-min_date="+1d" data-max_date="+12w" data-default_date="2020-09-15" id="dp1600188748809" style="position: static; zoom: 1;">
						<div class="ui-datepicker-inline ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all" style="display: block;">
							<div class="ui-datepicker-header ui-widget-header ui-helper-clearfix ui-corner-all">
								<a class="ui-datepicker-prev ui-corner-all ui-state-disabled" title="Previous">
									<span class="ui-icon ui-icon-circle-triangle-w">Previous</span>
								</a>
								<a class="ui-datepicker-next ui-corner-all" data-handler="next" data-event="click" title="Next">
									<span class="ui-icon ui-icon-circle-triangle-e">Next</span>
								</a>
								<div class="ui-datepicker-title">
									<span class="ui-datepicker-month">August</span>&nbsp;<span class="ui-datepicker-year">2025</span>
								</div>
							</div>
							<table class="ui-datepicker-calendar">
								<thead>
									<tr>
										<th scope="col"><span title="Monday">M</span></th>
										<th scope="col"><span title="Tuesday">T</span></th>
										<th scope="col"><span title="Wednesday">W</span></th>
										<th scope="col"><span title="Thursday">T</span></th>
										<th scope="col"><span title="Friday">F</span></th>
										<th scope="col" class="ui-datepicker-week-end"><span title="Saturday">S</span></th>
										<th scope="col" class="ui-datepicker-week-end"><span title="Sunday">S</span></th>
									</tr>
								</thead>
								<tbody>
									<tr>
										<td class=" ui-datepicker-other-month ui-datepicker-unselectable ui-state-disabled not_bookable bookable" title="This date is available">
											<span class="ui-state-default">27</span>
										</td>
										<td class=" ui-datepicker-other-month ui-datepicker-unselectable ui-state-disabled not_bookable bookable" title="This date is available">
											<span class="ui-state-default">28</span>
										</td>
										<td class=" ui-datepicker-other-month ui-datepicker-unselectable ui-state-disabled not_bookable bookable" title="This date is available">
											<span class="ui-state-default">29</span>
										</td>
										<td class=" ui-datepicker-other-month ui-datepicker-unselectable ui-state-disabled not_bookable bookable" title="This date is available">
											<span class="ui-state-default">30</span>
										</td>
										<td class=" ui-datepicker-other-month ui-datepicker-unselectable ui-state-disabled not_bookable bookable" title="This date is available">
											<span class="ui-state-default">31</span>
										</td>
										<td class=" ui-datepicker-week-end ui-datepicker-unselectable ui-state-disabled bookable" title="This date is available">
											<span class="ui-state-default">1</span>
										</td>
										<td class=" ui-datepicker-week-end ui-datepicker-unselectable ui-state-disabled bookable" title="This date is available">
											<span class="ui-state-default">2</span>
										</td>
									</tr>
									<tr>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">3</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">4</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">5</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">6</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">7</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">8</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">9</a>
										</td>
									</tr>
									<tr>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">10</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">11</a>
										</td>
										<td class=" bookable ui-datepicker-current-day ui-datepicker-today" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">12</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">13</a>
										</td>
										<td class=" bookable-range selection-start-date ui-datepicker-current-day" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default ui-state-active" href="#">14</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">15</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">16</a>
										</td>
									</tr>
									<tr>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">17</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">18</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">19</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">20</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">21</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">22</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">23</a>
										</td>
									</tr>
									<tr>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">24</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">25</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">26</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">27</a>
										</td>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">28</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">29</a>
										</td>
										<td class=" ui-datepicker-week-end bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">30</a>
										</td>
									</tr>
									<tr>
										<td class=" bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="0" data-year="2025">
											<a class="ui-state-default" href="#">31</a>
										</td>
										<td class=" ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">1</a>
										</td>
										<td class=" ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">2</a>
										</td>
										<td class=" ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">3</a>
										</td>
										<td class=" ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">4</a>
										</td>
										<td class=" ui-datepicker-week-end ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">5</a>
										</td>
										<td class=" ui-datepicker-week-end ui-datepicker-other-month bookable" title="This date is available" data-handler="selectDay" data-event="click" data-month="1" data-year="2025">
											<a class="ui-state-default ui-priority-secondary" href="#">6</a>
										</td>
									</tr>
								</tbody>
							</table>
						</div>
					</div>
					<div class="wc-bookings-date-picker-date-fields" style="display: none;">
						<label>
							<input type="text" autocomplete="off" name="wc_bookings_field_start_date_month" placeholder="mm" size="2" class="required_for_calculation booking_date_month">
							<span>Month</span>
						</label> / 
						<label>
							<input type="text" autocomplete="off" name="wc_bookings_field_start_date_day" placeholder="dd" size="2" class="required_for_calculation booking_date_day">
							<span>Day</span>
						</label> / 
						<label>
							<input type="text" autocomplete="off" value="2020" name="wc_bookings_field_start_date_year" placeholder="YYYY" size="4" class="required_for_calculation booking_date_year">
							<span>Year</span>
						</label>
					</div>
					<?php if ( 'fixed' === $ecwb_get_timeslots_meta ) { ?>
						<div class="form-field form-field-wide" style="position: static; zoom: 1;">
							<ul class="block-picker">
								<li class="block" data-block="0700">
									<a href="#" data-value="2020-09-17T07:00:00+0000" style="width: 77px; height: 33px;">7:00 am</a>
								</li>
								<li class="block" data-block="0900">
									<a href="#" data-value="2020-09-17T09:00:00+0000" style="width: 77px; height: 33px;">9:00 am</a>
								</li>
								<li class="block" data-block="1100">
									<a href="#" data-value="2020-09-17T11:00:00+0000" style="width: 77px; height: 33px;">11:00 am</a>
								</li>
								<li class="block" data-block="1300">
									<a href="#" data-value="2020-09-17T13:00:00+0000" style="width: 77px; height: 33px;">1:00 pm</a>
								</li>
								<li class="block" data-block="1500">
									<a href="#" data-value="2020-09-17T15:00:00+0000" style="width: 77px; height: 33px;">3:00 pm</a>
								</li>
								<li class="block" data-block="1700">
									<a href="#" data-value="2020-09-17T17:00:00+0000" style="width: 77px; height: 33px;">5:00 pm</a>
								</li>
							</ul>
							<input type="hidden" class="required_for_calculation" name="wc_bookings_field_start_date_time" id="wc_bookings_field_start_date" value="">
						</div>
						<div class="timezone-details" style="display: none;">
							<input type="hidden" name="wc_bookings_field_start_date_local_timezone">
						</div>
					<?php } ?>
					<?php if ( 'customer' === $ecwb_get_timeslots_meta ) { ?>
						<div class="form-field form-field-wide">
							<div class="block-picker wc-bookings-time-block-picker" style="position: relative; zoom: 1;">
								<div class="wc-bookings-start-time-container" data-product-id="262" data-blocks="[1623888000,1623891600,1623895200,1623898800,1623902400,1623906000,1623909600,1623913200,1623916800,1623920400,1623924000,1623927600,1623931200,1623934800,1623938400,1623942000,1623945600,1623949200,1623952800,1623956400,1623960000,1623963600,1623967200,1623970800,1623801600,1623805200,1623808800,1623812400,1623816000,1623819600,1623823200,1623826800,1623830400,1623834000,1623837600,1623841200,1623844800,1623848400,1623852000,1623855600,1623859200,1623862800,1623866400,1623870000,1623873600,1623877200,1623880800,1623884400]">
									<label for="wc-bookings-form-start-time">Starts</label>
									<select id="wc-bookings-form-start-time" name="start_time">
										<option value="0">Start time</option>
										<option data-block="2300" value="2021-06-16T23:00:00+0000">12:00 am</option>
										<option data-block="0000" value="2021-06-17T00:00:00+0000">1:00 am</option>
										<option data-block="0100" value="2021-06-17T01:00:00+0000">2:00 am</option>
										<option data-block="0200" value="2021-06-17T02:00:00+0000">3:00 am</option>
										<option data-block="0300" value="2021-06-17T03:00:00+0000">4:00 am</option>
										<option data-block="0400" value="2021-06-17T04:00:00+0000">5:00 am</option>
										<option data-block="0500" value="2021-06-17T05:00:00+0000">6:00 am</option>
										<option data-block="0600" value="2021-06-17T06:00:00+0000">7:00 am</option>
										<option data-block="0700" value="2021-06-17T07:00:00+0000">8:00 am</option>
										<option data-block="0800" value="2021-06-17T08:00:00+0000">9:00 am</option>
										<option data-block="0900" value="2021-06-17T09:00:00+0000">10:00 am</option>
										<option data-block="1000" value="2021-06-17T10:00:00+0000">11:00 am</option>
										<option data-block="1100" value="2021-06-17T11:00:00+0000">12:00 pm</option>
										<option data-block="1200" value="2021-06-17T12:00:00+0000">1:00 pm</option>
										<option data-block="1300" value="2021-06-17T13:00:00+0000">2:00 pm</option>
										<option data-block="1400" value="2021-06-17T14:00:00+0000">3:00 pm</option>
										<option data-block="1500" value="2021-06-17T15:00:00+0000">4:00 pm</option>
										<option data-block="1600" value="2021-06-17T16:00:00+0000">5:00 pm</option>
										<option data-block="1700" value="2021-06-17T17:00:00+0000">6:00 pm</option>
										<option data-block="1800" value="2021-06-17T18:00:00+0000">7:00 pm</option>
										<option data-block="1900" value="2021-06-17T19:00:00+0000">8:00 pm</option>
										<option data-block="2000" value="2021-06-17T20:00:00+0000">9:00 pm</option>
										<option data-block="2100" value="2021-06-17T21:00:00+0000">10:00 pm</option>
										<option data-block="2200" value="2021-06-17T22:00:00+0000">11:00 pm</option>
									</select>
								</div>
								&nbsp;&nbsp;
								<div class="wc-bookings-end-time-container">
									<label for="wc-bookings-form-end-time">Ends</label>
									<select id="wc-bookings-form-end-time" name="end_time">
										<option value="0">End time</option>
									</select>
								</div>
							</div>
							<input type="hidden" name="wc_bookings_field_duration" value="1" class="wc_bookings_field_duration">
							<input type="hidden" class="required_for_calculation" name="wc_bookings_field_start_date_time" id="wc_bookings_field_start_date">
						</div>
					<?php } ?>
					<?php if ( true === $ecwb_get_bookingtype_meta ) { ?>
						<div class="wc-bookings-date-picker-date-fields">
							<span>Check-in:</span><br>
							<label>
								<input type="text" autocomplete="off" name="wc_bookings_field_start_date_month" placeholder="mm" size="2" class="booking_date_month">
								<span>Month</span>
							</label> / 
							<label>
								<input type="text" autocomplete="off" name="wc_bookings_field_start_date_day" placeholder="dd" size="2" class="booking_date_day">
								<span>Day</span>
							</label> / 
							<label>
								<input type="text" autocomplete="off" value="2021" name="wc_bookings_field_start_date_year" placeholder="YYYY" size="4" class="booking_date_year">
								<span>Year</span>
							</label>
						</div>
						<div class="wc-bookings-date-picker-date-fields">
							<span>Check-out:</span><br>
							<label>
								<input type="text" autocomplete="off" name="wc_bookings_field_start_date_to_month" placeholder="mm" size="2" class="booking_to_date_month">
								<span>Month</span>
							</label> / 
							<label>
								<input type="text" name="wc_bookings_field_start_date_to_day" placeholder="dd" size="2" class="booking_to_date_day">
								<span>Day</span>
							</label> / 
							<label>
								<input type="text" autocomplete="off" value="2021" name="wc_bookings_field_start_date_to_year" placeholder="YYYY" size="4" class="booking_to_date_year">
								<span>Year</span>
							</label>
						</div>
					<?php } ?>
				</fieldset>
				<div class="wc-bookings-booking-cost" style="display:none" data-raw-price=""></div>
			<?php } ?>
			<?php if ( 'month' === $ecwb_get_duration_unit ) { ?>
				<div id="wc-bookings-booking-form" class="wc-bookings-booking-form">
					<div class="form-field form-field-wide">
						<div class="picker" data-is_range_picker_enabled="0"></div>
						<ul class="block-picker">
							<li class="" data-block="202502">
								<a href="#" data-value="2025-02" style="width: 174.703px; height: 40px;">Feb 2025</a>
							</li>
							<li class="" data-block="202503">
								<a href="#" data-value="2025-03" style="width: 174.703px; height: 40px;">Mar 2025</a>
							</li>
							<li class="" data-block="202504">
								<a href="#" data-value="2025-04" style="width: 174.703px; height: 40px;">Apr 2025</a>
							</li>
							<li class="" data-block="202505">
								<a href="#" data-value="2025-05" style="width: 174.703px; height: 40px;">May 2025</a>
							</li>
							<li class="" data-block="202506">
								<a href="#" data-value="2025-06" style="width: 174.703px; height: 40px;">Jun 2025</a>
							</li>
							<li class="" data-block="202507">
								<a href="#" data-value="2025-07" style="width: 174.703px; height: 40px;">Jul 2025</a>
							</li>
							<li class="" data-block="202508">
								<a href="#" data-value="2025-08" style="width: 174.703px; height: 40px;">Aug 2025</a>
							</li>
							<li class="" data-block="202509">
								<a href="#" data-value="2025-09" style="width: 174.703px; height: 40px;">Sep 2025</a>
							</li>
							<li class="" data-block="202510">
								<a href="#" data-value="2025-10" style="width: 174.703px; height: 40px;">Oct 2025</a>
							</li>
							<li class="" data-block="202511">
								<a href="#" data-value="2025-11" style="width: 174.703px; height: 40px;">Nov 2025</a>
							</li>
							<li class="" data-block="202512">
								<a href="#" data-value="2025-12" style="width: 174.703px; height: 40px;">Dec 2025</a>
							</li>
							<li class="" data-block="202501">
								<a href="#" data-value="2025-01" style="width: 174.703px; height: 40px;">Jan 2025</a>
							</li>
						</ul>
						<input type="hidden" name="wc_bookings_field_start_date_yearmonth" id="wc_bookings_field_start_date" value="2025-06">
					</div>
					<div class="wc-bookings-booking-cost" style="zoom: 1;" data-raw-price="">
						Booking cost: <strong>
							<span class="woocommerce-Price-amount amount">
								<bdi><span class="woocommerce-Price-currencySymbol">$</span>110.00</bdi>
							</span>
						</strong>
					</div>
				</div>
			<?php } ?>
			</div>
			<input type="hidden" name="add-to-cart" value="96" class="wc-booking-product-id">
			<button type="submit" class="wc-bookings-booking-form-button single_add_to_cart_button button alt disabled">Book now</button>
		</form>
		<?php
	}
}