<?php
/**
 * Elementor Connector for WooCommerce Bookings - Bookings Form Widget.
 *
 * Elementor widget that inserts bookable form on the single product page.
 *
 * @since 1.0.0
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Popover_Toggle;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * The Elementor widget used in admin.
 *
 * @package    Elementor_Connector_For_Woocommerce_Bookings
 * @subpackage Elementor_Connector_For_Woocommerce_Bookings/admin
 */
class Elementor_Connector_For_Woocommerce_Bookings_Single_Product_Form extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'ecwb-booking-form';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'WC Bookings Form - Products', 'elementor-connector-for-woocommerce-bookings' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-thumbnails-half';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'woocommerce-elements-single' );
	}

	/**
	 * Get widget keywords.
	 *
	 * @since 1.0.0
	 * @return array Widget keywords.
	 */
	public function get_keywords() {
		return array( 'woocommerce', 'shop', 'store', 'cart', 'product', 'button', 'add to cart', 'bookings', 'form' );
	}

	/**
	 * Check if bookable product has persons configured.
	 *
	 * @since 1.0.0
	 * @return bool Returns true if persons are configured, false otherwise.
	 */
	public function ecwb_has_persons() {
		$product_id = get_the_ID();
		$product    = false; // FIX: Initialize $product.
		if ( $product_id ) {
			$product = wc_get_product( $product_id );
		}
		if ( ! $product ) {
			return false;
		}
		if ( 'booking' !== $product->get_type() ) {
			return false;
		}
		return (bool) $product->has_persons();
	}

	/**
	 * Check if bookable product has resources configured.
	 *
	 * @since 1.0.0
	 * @return bool Returns true if resources are configured, false otherwise.
	 */
	public function ecwb_has_resources() {
		$product_id = get_the_ID();
		$product    = false; // FIX: Initialize $product.
		if ( $product_id ) {
			$product = wc_get_product( $product_id );
		}
		if ( ! $product ) {
			return false;
		}
		if ( 'booking' !== $product->get_type() ) {
			return false;
		}
		return (bool) $product->has_resources();
	}

	/**
	 * Check if bookable product has timeslots configured.
	 *
	 * @since 1.0.0
	 * @return mixed Returns 'fixed', 'customer', or false.
	 */
	public function ecwb_has_timeslots() {
		$product_id = get_the_ID();
		$product    = false; // FIX: Initialize $product.
		if ( $product_id ) {
			$product = wc_get_product( $product_id );
		}
		// For preview or if no valid product is found, assume a demo fixed timeslots type.
		if ( ! $product ) {
			return 'fixed';
		}
		if ( ! in_array( $product->get_type(), array( 'booking', 'accommodation-booking' ), true ) ) {
			return false;
		}
		$timeslots_type = $product->get_duration_type();
		if ( 'fixed' === $timeslots_type ) {
			return 'fixed';
		}
		if ( 'customer' === $timeslots_type ) {
			return 'customer';
		}
		return false;
	}

	/**
	 * Check if bookable product uses "month" as duration unit.
	 *
	 * @since 1.2.0
	 * @return string Returns the duration unit, e.g. 'month', 'day', etc.
	 */
	public function ecwb_is_monthly() {
		$product_id = get_the_ID();
		$product    = false; // Initialize product variable.
		if ( $product_id ) {
			$product = wc_get_product( $product_id );
		}

		// If no product is found (e.g. in preview), assume a monthly product.
		if ( empty( $product ) ) {
			return 'month';
		}

		// Make sure the product type is set to 'booking'.
		if ( 'booking' !== $product->get_type() ) {
			// If not a booking product, you can choose a default (here we return 'day').
			return 'day';
		}

		$duration_unit = $product->get_duration_unit();
		if ( empty( $duration_unit ) ) {
			$duration_unit = 'day';
		}

		// Fallback return.
		return $duration_unit;
	}

	/**
	 * Check if the product is an accommodation booking.
	 *
	 * @since 1.0.0
	 * @return bool Returns true if the product is an accommodation booking, false otherwise.
	 */
	public function ecwb_is_accommodation() {
		$product_id = get_the_ID();
		$product    = false; // FIX: Initialize $product.
		if ( $product_id ) {
			$product = wc_get_product( $product_id );
		}
		if ( ! $product ) {
			return false;
		}
		if ( 'accommodation-booking' !== $product->get_type() ) {
			return false;
		}
		return true;
	}

	/**
	 * Generate Elementor option panel for widget.
	 *
	 * @since 1.0.0
	 */
	protected function register_controls() {
		// Retrieve configuration values from product.
		$ecwb_get_persons_meta     = $this->ecwb_has_persons();
		$ecwb_get_resources_meta   = $this->ecwb_has_resources();
		$ecwb_get_timeslots_meta   = $this->ecwb_has_timeslots();
		$ecwb_get_bookingtype_meta = $this->ecwb_is_accommodation();
		$ecwb_get_duration_unit    = $this->ecwb_is_monthly();

		// Determine if the Calendar section should be displayed.
		$ecwb_should_display_calendar = ( 'month' !== $ecwb_get_duration_unit ) ? true : false;

		// Only show the Calendar section if the duration unit is NOT "month".
		if ( true === $ecwb_should_display_calendar ) {
			$this->start_controls_section(
				'ecwb_calendar_styles',
				array(
					'label' => __( 'Calendar', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-calendar.php';
			$this->end_controls_section();
		}

		if ( true === $ecwb_get_persons_meta ) {
			$this->start_controls_section(
				'ecwb_person_styles',
				array(
					'label' => __( 'Persons', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-persons.php';
			$this->end_controls_section();
		}

		if ( true === $ecwb_get_resources_meta ) {
			$this->start_controls_section(
				'ecwb_resource_styles',
				array(
					'label' => __( 'Resources', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-resources.php';
			$this->end_controls_section();
		}

		if ( true === $ecwb_get_bookingtype_meta ) {
			$this->start_controls_section(
				'ecwb_accommodation_styles',
				array(
					'label' => __( 'Check-in/out', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-accommodation.php';
			$this->end_controls_section();
		}

		if ( 'fixed' === $ecwb_get_timeslots_meta ) {
			$this->start_controls_section(
				'ecwb_timeslots_styles_fixed',
				array(
					'label' => __( 'Timeslots: Fixed', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-timeslots-fixed.php';
			$this->end_controls_section();
		}

		if ( 'customer' === $ecwb_get_timeslots_meta ) {
			$this->start_controls_section(
				'ecwb_timeslots_styles_customer',
				array(
					'label' => __( 'Timeslots: Customer Defined', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-timeslots-customer.php';
			$this->end_controls_section();
		}

		$this->start_controls_section(
			'ecwb_costs_styles',
			array(
				'label' => __( 'Costs & Notices', 'elementor-connector-for-woocommerce-bookings' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-costs.php';
		$this->end_controls_section();

		$this->start_controls_section(
			'ecwb_buttons_styles',
			array(
				'label' => __( 'Buttons', 'elementor-connector-for-woocommerce-bookings' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-buttons.php';
		$this->end_controls_section();

		if ( 'yes' === get_option( 'woocommerce_show_marketplace_suggestions' ) ) {
			$this->start_controls_section(
				'ecwb_templates',
				array(
					'label' => __( 'Templates', 'elementor-connector-for-woocommerce-bookings' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				)
			);
			require_once plugin_dir_path( __DIR__ ) . 'admin/partials/elementor-connector-for-woocommerce-bookings-widget-templates.php';
			$this->end_controls_section();
		}
	}

	/**
	 * Render widget in HTML on front-end.
	 *
	 * @since 1.0.0
	 */
	protected function render() {
		$product_id = get_the_ID();
		if ( ! $product_id ) {
			return;
		}
		$product = wc_get_product( $product_id );
		if ( empty( $product ) ) {
			return;
		}

		// Detect if we're in Elementor editor mode.
		$is_editor_mode = false;
		if ( isset( \Elementor\Plugin::$instance ) && method_exists( \Elementor\Plugin::$instance->editor, 'is_edit_mode' ) ) {
			$is_editor_mode = \Elementor\Plugin::$instance->editor->is_edit_mode();
		}

		// Only booking products have the get_duration_unit() method.
		if ( method_exists( $product, 'get_duration_unit' ) ) {
			$duration_unit = $product->get_duration_unit();
		} else {
			// For non-bookable products, set a default value.
			$duration_unit = 'day';
		}

		// If the product is not a booking product, then:
		// - On the front-end, you might not want to show any calendar.
		// - In editor mode, however, we want to show demo calendar data.
		if ( 'booking' !== $product->get_type() && $is_editor_mode ) {
			$duration_unit = 'day';
		}

		// Fallback: if no duration unit was returned, default to 'day'.
		if ( empty( $duration_unit ) ) {
			$duration_unit = 'day';
		}

		// Now, if the duration unit is "month", show the month markup.
		if ( $is_editor_mode ) {
			if ( 'month' === $duration_unit ) {
				?>
				<div id="wc-bookings-booking-form" class="wc-bookings-booking-form" style="">
					<div class="form-field form-field-wide">
						<div class="picker" data-is_range_picker_enabled="0"></div>
						<ul class="block-picker">
							<li class="" data-block="202502">
								<a href="#" data-value="2025-02" style="width: 174.703px; height: 40px;">Feb 2025</a>
							</li>
							<li class="" data-block="202503">
								<a href="#" data-value="2025-03" style="width: 174.703px; height: 40px;">Mar 2025</a>
							</li>
							<li class="" data-block="202504">
								<a href="#" data-value="2025-04" style="width: 174.703px; height: 40px;">Apr 2025</a>
							</li>
							<li class="" data-block="202505">
								<a href="#" data-value="2025-05" style="width: 174.703px; height: 40px;">May 2025</a>
							</li>
							<li class="" data-block="202506">
								<a href="#" data-value="2025-06" style="width: 174.703px; height: 40px;">Jun 2025</a>
							</li>
							<li class="" data-block="202507">
								<a href="#" data-value="2025-07" style="width: 174.703px; height: 40px;">Jul 2025</a>
							</li>
							<li class="" data-block="202508">
								<a href="#" data-value="2025-08" style="width: 174.703px; height: 40px;">Aug 2025</a>
							</li>
							<li class="" data-block="202509">
								<a href="#" data-value="2025-09" style="width: 174.703px; height: 40px;">Sep 2025</a>
							</li>
							<li class="" data-block="202510">
								<a href="#" data-value="2025-10" style="width: 174.703px; height: 40px;">Oct 2025</a>
							</li>
							<li class="" data-block="202511">
								<a href="#" data-value="2025-11" style="width: 174.703px; height: 40px;">Nov 2025</a>
							</li>
							<li class="" data-block="202512">
								<a href="#" data-value="2025-12" style="width: 174.703px; height: 40px;">Dec 2025</a>
							</li>
							<li class="" data-block="202601">
								<a href="#" data-value="2026-01" style="width: 174.703px; height: 40px;">Jan 2026</a>
							</li>
						</ul>
						<!-- Adjust the default value as needed. -->
						<input type="hidden" name="wc_bookings_field_start_date_yearmonth" id="wc_bookings_field_start_date" value="<?php echo esc_attr( gmdate( 'Y-m' ) ); ?>">
					</div>
					<div class="wc-bookings-booking-cost" style="zoom: 1;" data-raw-price="">
						<?php esc_html_e( 'Booking Cost:', 'elementor-connector-for-woocommerce-bookings' ); ?>
						<strong>
							<span class="woocommerce-Price-amount amount">
								<bdi>
									<span class="woocommerce-Price-currencySymbol"><?php echo esc_html( get_woocommerce_currency_symbol() ); ?></span>
									<?php
									$price = $product->get_price();
									echo esc_html( number_format( $price, 2 ) );
									?>
								</bdi>
							</span>
						</strong>
					</div>
				</div>
				<?php
			} else {
				// Otherwise, load the admin display partial.
				require_once plugin_dir_path( __DIR__ ) . 'admin/partials/widget/elementor-connector-for-woocommerce-bookings-admin-display.php';
			}
		}

		if ( ! $is_editor_mode ) {
			global $product;

			$settings = $this->get_settings_for_display();
			$product  = wc_get_product();

			if ( empty( $product ) ) {
				return;
			}

			$product_type = $product->get_type();

			// Check if the product being shown on the front-end is bookable.
			if ( ( 'booking' === $product_type ) || ( 'accommodation-booking' === $product_type ) ) {

				// If product is bookable, hide all instances of the "Add to Cart" widget in Elementor.
				add_filter(
					'elementor/frontend/widget/should_render',
					function ( $should_render, $element ) {
						$type = $element->get_name();
						if ( 'woocommerce-product-add-to-cart' === $type ) {
							return false;
						} else {
							return true;
						}
					},
					10,
					3
				);

				?>

				<div class="elementor-add-to-cart elementor-product-<?php echo esc_attr( wc_get_product()->get_type() ); ?>">
					<?php

					// Use the following do_action in Bookings rather than calling the WC core function woocommerce_template_single_add_to_cart().
					echo esc_html( do_action( 'woocommerce_booking_add_to_cart' ) );

					?>
				</div>

				<?php
			}
		}
	}

	/**
	 * Generate the live preview in the Elementor admin area.
	 *
	 * @since 1.0.0
	 */
	public function content_template() {
		$this->render();
	}

	/**
	 * Render backbone.js view of widget preview.
	 *
	 * @since 1.0.0
	 */
	public function render_plain_content() {
		$this->content_template();
	}
}
